package com.ff.common.mapper;

import java.util.List;
import com.ff.common.domain.Lang;

/**
 * 系统语种管理 Mapper接口
 * 
 * @author shi
 * @date 2025-02-10
 */
public interface LangMapper 
{
    /**
     * 查询系统语种管理 
     * 
     * @param id 系统语种管理 主键
     * @return 系统语种管理 
     */
     Lang selectLangById(Long id);

    /**
     * 查询系统语种管理 列表
     * 
     * @param lang 系统语种管理 
     * @return 系统语种管理 集合
     */
     List<Lang> selectLangList(Lang lang);

    /**
     * 新增系统语种管理 
     * 
     * @param lang 系统语种管理 
     * @return 结果
     */
     int insertLang(Lang lang);

    /**
     * 修改系统语种管理 
     * 
     * @param lang 系统语种管理 
     * @return 结果
     */
     int updateLang(Lang lang);

    /**
     * 删除系统语种管理 
     * 
     * @param id 系统语种管理 主键
     * @return 结果
     */
     int deleteLangById(Long id);

    /**
     * 批量删除系统语种管理 
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteLangByIds(Long[] ids);
}
